#!/usr/bin/env bash
set -u

NODE_TYPE="${NODE_TYPE:-compute_skylake}"

lease_name="$RESOURCE_NAME"
public_network_id=$(openstack network show public -f value -c id)

echo "Requesting lease for:"
echo " - $NUM_NODES bare metal node (type=$NODE_TYPE)"
echo " - $NUM_NODES Floating IP"
echo

echo "Reserving $NUM_NODES"

blazar lease-create \
  --physical-reservation min=$NUM_NODES,max=$NUM_NODES,resource_properties="[\"=\", \"\$node_type\", \"$NODE_TYPE\"]" \
  --reservation resource_type=virtual:floatingip,network_id="$public_network_id",amount=$NUM_NODES \
  --start-date "$(date -u +'%Y-%m-%d %H:%M' -d'+1 minute')" \
  --end-date "$(date -u +'%Y-%m-%d %H:%M' -d'+1 day')" \
  "$lease_name"

echo "Waiting for lease to start"
echo
attempts=0
wait_lease() {
  sleep 5
  attempts=$((attempts+1))
  printf "."
  [[ $attempts -gt 60 ]] && return 1
}
until [[ $(blazar lease-show "$lease_name" -f value -c status) == "ACTIVE" ]]; do wait_lease; done
echo
echo "Lease started successfully!"

reservations=$(blazar lease-show "$lease_name" -f json \
  | jq -r '.reservations')
host_reservation_id=$(jq -rs 'map(select(.resource_type=="physical:host"))[].id' <<<"$reservations")
fip_reservation_id=$(jq -rs 'map(select(.resource_type=="virtual:floatingip"))[].id' <<<"$reservations")

print_string_delim() {
  while IFS=$1 read -ra ADDR; do
    for i in "${ADDR[@]}"; do
      echo $i
    done
  done
}

fip=$(openstack floating ip list --tags "reservation:$fip_reservation_id" -f json)
fip_ids=$(jq -r '.[]["ID"]' <<<"$fip")
fip_addrs=$(jq -r '.[]["Floating IP Address"]' <<<"$fip")

export FLOATING_IP_IDS=($fip_ids)
export FLOATING_IPS=($fip_addrs)
export RESERVATION_ID=$host_reservation_id
echo
echo "Stack parameters:"
echo " - floating_ip:"
print_string_delim ' ' <<< $fip_ids
echo "   (exported as FLOATING_IP_IDS)"
echo " - reservation_id=$host_reservation_id"
echo "   (exported as RESERVATION_ID)"
echo
echo "Also exported public IP address as FLOATING_IP:"
print_string_delim ' ' <<< $fip_addrs